tests.models package
====================

Subpackages
-----------

.. toctree::
   :maxdepth: 4

   tests.models.input
   tests.models.managers
   tests.models.output
   tests.models.pipeline

Submodules
----------

tests.models.test\_analysis module
----------------------------------

.. automodule:: tests.models.test_analysis
   :members:
   :undoc-members:
   :show-inheritance:

tests.models.test\_analysis\_version module
-------------------------------------------

.. automodule:: tests.models.test_analysis_version
   :members:
   :undoc-members:
   :show-inheritance:

tests.models.test\_category module
----------------------------------

.. automodule:: tests.models.test_category
   :members:
   :undoc-members:
   :show-inheritance:

tests.models.test\_run module
-----------------------------

.. automodule:: tests.models.test_run
   :members:
   :undoc-members:
   :show-inheritance:


Module contents
---------------

.. automodule:: tests.models
   :members:
   :undoc-members:
   :show-inheritance:
